@@ -114,9 +114,10 @@ class TelegramBot:
             return None
 
     # async def echo(self, conversation_id: str, user_id: str, message: str):
-    async def echo(self, update: Update, context: ContextTypes.DEFAULT_TYPE):
+    async def echo(self, update: Update, context: ContextTypes.DEFAULT_TYPE, message: str = ""):
         user_id = str(update.effective_user.id)
-        message = update.message.text
+        if not message:
+            message = update.message.text
         bot = self.choose_bot(user_id)
         if not bot:
             logger.info('no available bot')
@@ -124,13 +125,13 @@ class TelegramBot:
             #queue message
             return False
         try:
-            count = 0
             async for msg in bot.send_message(user_id, message):
-                await update.message.reply_text(msg)
-                count += 1
-            await asyncio.sleep(1.0)
-            if count > 1:
-                pass
+                for _ in range(3):
+                    try:
+                        await update.message.reply_text(msg)
+                        break
+                    except Exception as e:
+                        logger.exception(e)
             await update.message.reply_text("[END]")
             return True
         except Exception as e:
@@ -183,7 +184,7 @@ class TelegramBot:
                     await question.update.message.reply_text(''.join(msgs))
                     handled_question.append(user_id)
                 except Exception as e:
-                    logger.info("%s", str(e))
+                    logger.exception(e)
                     continue
             for question in handled_question:
                 del self.saved_questions[question]
@@ -192,9 +193,9 @@ class TelegramBot:
         user_id = str(update.effective_user.id)
         self.saved_questions[user_id] = SavedQuestion(update, context)
 
-    async def handle_private_message(self, update: Update, context: ContextTypes.DEFAULT_TYPE):
+    async def handle_private_message(self, update: Update, context: ContextTypes.DEFAULT_TYPE, message: str = ""):
         try:
-            await self.echo(update, context)
+            await self.echo(update, context, message)
         except Exception as e:
             logger.exception(e)
             if self.developer_user_id:
